@@ -4,7 +4,7 @@ require 'socket'
 mysql_port = nil
 (1025..3600).to_a.shuffle.each do |port|
   begin
-    s = TCPSocket.new 'localhost', port
+    s = TCPSocket.new '127.0.0.1', port
     s.close
   rescue Errno::ECONNREFUSED
     mysql_port = port
